Goldman Sans is a trademark of Goldman Sachs and distributed under the Goldman Sachs Restricted Font License
import_goldman_sans()There is an option hrbrthemes.loadfonts which -- if set to TRUE -- will
call extrafont::loadfonts() to register non-core fonts with R PDF & PostScript
devices. If you are running under Windows, the package calls the same function
to register non-core fonts with the Windows graphics device.